summaryrefslogtreecommitdiffstats
path: root/misc/scripts/validate_extension_api.sh
diff options
context:
space:
mode:
Diffstat (limited to 'misc/scripts/validate_extension_api.sh')
-rwxr-xr-xmisc/scripts/validate_extension_api.sh10
1 files changed, 8 insertions, 2 deletions
diff --git a/misc/scripts/validate_extension_api.sh b/misc/scripts/validate_extension_api.sh
index db2d053f73..aa0d6b7155 100755
--- a/misc/scripts/validate_extension_api.sh
+++ b/misc/scripts/validate_extension_api.sh
@@ -58,8 +58,14 @@ while read -r file; do
expected_errors="$(mktemp)"
get_expected_output "$file"
- # Download the reference extension_api.json
- wget -nv --retry-on-http-error=503 --tries=5 --timeout=60 -cO "$reference_file" "https://raw.githubusercontent.com/godotengine/godot-cpp/godot-$reference_tag/gdextension/extension_api.json" || has_problems=1
+ if [[ $file == *redot* ]]; then
+ # Download the Redot reference extension_api.json
+ wget -nv --retry-on-http-error=503 --tries=5 --timeout=60 -cO "$reference_file" "https://raw.githubusercontent.com/Redot-Engine/redot-cpp/$reference_tag/gdextension/extension_api.json" || has_problems=1
+ else
+ # Download the Godot reference extension_api.json
+ wget -nv --retry-on-http-error=503 --tries=5 --timeout=60 -cO "$reference_file" "https://raw.githubusercontent.com/Redot-Engine/redot-cpp/godot-$reference_tag/gdextension/extension_api.json" || has_problems=1
+ fi
+
# Validate the current API against the reference
"$1" --headless --validate-extension-api "$reference_file" 2>&1 | tee "$validate" | awk '!/^Validate extension JSON:/' - || true
# Collect the expected and actual validation errors